/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.sling.taglib.selectors;

import com.squeakysand.commons.lang.StringUtils;
import com.squeakysand.jsp.tagext.BodyContent;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;
import com.squeakysand.sling.SlingUtils;
import com.squeakysand.sling.taglib.SlingSimpleTagSupport;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.apache.sling.api.SlingHttpServletRequest;

/**
 * Selectively executes the body of the tag depending on whether the specified request selector is or is not present.
 * 
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
@JspTag(bodyContent = BodyContent.SCRIPTLESS)
public class IfSelectorTag extends SlingSimpleTagSupport {

    private String isNotPresent;
    private String isPresent;

    @Override
    public void doTag() throws JspException, IOException {
        SlingHttpServletRequest slingRequest = (SlingHttpServletRequest) getRequest();
        if (StringUtils.isNotNullOrEmpty(isPresent)) {
            Boolean isSelectorPresent = SlingUtils.isSelectorPresent(isPresent, slingRequest);
            if (isSelectorPresent) {
                getJspBody().invoke(null);
            }
        } else if (StringUtils.isNotNullOrEmpty(isNotPresent)) {
            Boolean isSelectorNotPresent = !SlingUtils.isSelectorPresent(isNotPresent, slingRequest);
            if (isSelectorNotPresent) {
                getJspBody().invoke(null);
            }
        } else {
            throw new JspException("one of isPresent or isNotPresent must be set");
        }
    }

    public String getIsNotPresent() {
        return isNotPresent;
    }

    public String getIsPresent() {
        return isPresent;
    }

    /**
     * The selector to check is not present. If the selector is not present, the body of the tag will be executed.
     * 
     * @param selectorName
     *            the new value for the <code>isNotPresent</code> property.
     */
    @JspTagAttribute(rtexprvalue = true)
    public void setIsNotPresent(String selectorName) {
        isNotPresent = selectorName;
    }

    /**
     * The selector to check is present. If the selector is present, the body of the tag will be executed.
     * 
     * @param selectorName
     *            the new value for the <code>isPresent</code> property.
     */
    @JspTagAttribute(rtexprvalue = true)
    public void setIsPresent(String selectorName) {
        isPresent = selectorName;
    }

}
